@@ -4,10 +4,9 @@ import ev3sim.visual.utils as utils
 from ev3sim.simulation.interactor import IInteractor, fromOptions
 from ev3sim.simulation.loader import ScriptLoader
 from ev3sim.simulation.randomisation import Randomiser
-from ev3sim.objects.base import objectFactory
 from ev3sim.objects.utils import local_space_to_world_space
-from ev3sim.visual.manager import ScreenObjectManager
 from ev3sim.file_helper import find_abs
+from ev3sim.search_locations import device_locations
 
 
 class Device:
@@ -64,6 +63,7 @@ class IDeviceInteractor(IInteractor):
         self.index = f"{i1}-{i2}"
         self.items = kwargs.get("elements", [])
         self.port = kwargs.get("port")
+        self.zPos = kwargs.get("zPos", 0)
 
     def getPrefix(self):
         return f"{self.physical_object.key}-{self.name}-{self.index}-"
@@ -75,7 +75,7 @@ class IDeviceInteractor(IInteractor):
             self.items[x]["type"] = "object"
             if "visual" in self.items[x]:
                 self.items[x]["visual"]["zPos"] = (
-                    self.items[x]["visual"].get("zPos", 0) + self.physical_object.visual.zPos
+                    self.items[x]["visual"].get("zPos", 0) + self.physical_object.visual.zPos + self.zPos
                 )
             self.relative_positions.append(self.items[x]["position"])
         self.generated = ScriptLoader.instance.loadElements(self.items)
@@ -93,20 +93,20 @@ class IDeviceInteractor(IInteractor):
             )
             obj.rotation = self.physical_object.rotation + self.relative_rotation
             if isinstance(obj, PhysicsObject):
-                obj.body.position = obj.position
+                obj.body.position = [float(v) for v in obj.position]
                 obj.body.angle = obj.rotation
 
     def random(self):
         return Randomiser.getPortRandom(self.port_key).random()
 
 
-def initialise_device(deviceData, parentObj, index):
+def initialise_device(deviceData, parentObj, index, preview_mode=False):
     classes = find_abs("devices/classes.yaml")
     devices = yaml.safe_load(open(classes, "r"))
     name = deviceData["name"]
     if name not in devices:
         raise ValueError(f"Unknown device type {name}")
-    fname = find_abs(devices[name], allowed_areas=["local/devices/", "package/devices/"])
+    fname = find_abs(devices[name], allowed_areas=device_locations())
     with open(fname, "r") as f:
         try:
             config = yaml.safe_load(f)
@@ -129,8 +129,12 @@ def initialise_device(deviceData, parentObj, index):
                         "device_index": index,
                         "single_device_index": i,
                         "port": deviceData["port"],
+                        "zPos": deviceData.get("zPos", 0),
                     }
                 )
+                if preview_mode:
+                    for i in range(len(res.get("elements", []))):
+                        res["elements"][i]["physics"] = True
                 opt["kwargs"] = res
                 interactor = fromOptions(opt)
                 if not hasattr(parentObj, "device_interactors"):
