@@ -14,7 +14,9 @@ class ButtonInteractor(IDeviceInteractor):
     def handleEvent(self, event):
         if event.type == pygame.MOUSEBUTTONDOWN and event.button == 1:
             m_pos = screenspace_to_worldspace(event.pos)
-            shapes = World.instance.space.point_query(m_pos, 0.0, pymunk.ShapeFilter(mask=DYNAMIC_CATEGORY))
+            shapes = World.instance.space.point_query(
+                [float(v) for v in m_pos], 0.0, pymunk.ShapeFilter(mask=DYNAMIC_CATEGORY)
+            )
             if shapes:
                 max_z = max(pq.shape.obj.clickZ for pq in shapes)
                 shapes = [pq for pq in shapes if pq.shape.obj.clickZ == max_z]
